@@ -1,13 +1,16 @@
 from extras.plugins import PluginConfig
+from .version import __version__
 
-class NetBoxRisksConfig(PluginConfig):
+
+class UsersandcomputersConfig(PluginConfig):
     name = 'users_and_computers'
     verbose_name = 'Users and Computers'
     description = 'Manage AD Users and Workstations'
-    version = '0.3.6'
-    base_url = 'users_and_computers'
+    version = __version__
     author = 'Artur Shamsiev'
     author_email = 'me@z-lab.me'
+    required_settings = []
+    default_settings = {}
 
 
-config = NetBoxRisksConfig
+config = UsersandcomputersConfig # noqa
